@@ -47,9 +47,10 @@ use PPIx::Regexp::Constant qw{
     MINIMUM_PERL
     TOKEN_UNKNOWN
     TRUE
+    @CARP_NOT
 };
 
-our $VERSION = '0.055';
+our $VERSION = '0.062';
 
 =head2 accepts_perl
 
@@ -338,6 +339,24 @@ sub modifier_asserted {
     return;
 }
 
+=head2 next_element
+
+This method returns the next element, or nothing if there is none.
+
+Unlike L<next_sibling()|/next_sibling>, this will cross from the content
+of a structure into the elements that define the structure, or vice
+versa.
+
+=cut
+
+sub next_element {
+    my ( $self ) = @_;
+    my $parent = $self->_parent()
+	or return;
+    my $inx = $self->__my_inx();
+    return ( $parent->elements() )[ $inx + 1 ];
+}
+
 =head2 next_sibling
 
 This method returns the element's next sibling, or nothing if there is
@@ -347,7 +366,7 @@ none.
 
 sub next_sibling {
     my ( $self ) = @_;
-    my ( $method, $inx ) = $self->_my_inx()
+    my ( $method, $inx ) = $self->__my_nav()
 	or return;
     return $self->_parent()->$method( $inx + 1 );
 }
@@ -416,21 +435,68 @@ sub perl_version_removed {
     return undef;	## no critic (ProhibitExplicitReturnUndef)
 }
 
+=head2 previous_element
+
+This method returns the previous element, or nothing if there is none.
+
+Unlike L<previous_sibling()|/previous_sibling>, this will cross from
+the content of a structure into the elements that define the structure,
+or vice versa.
+
+=cut
+
+sub previous_element {
+    my ( $self ) = @_;
+    my $parent = $self->_parent()
+	or return;
+    my $inx = $self->__my_inx()
+	or return;
+    return ( $parent->elements() )[ $inx - 1 ];
+}
+
 =head2 previous_sibling
 
 This method returns the element's previous sibling, or nothing if there
 is none.
 
+This method is analogous to the same-named L<PPI::Element|PPI::Element>
+method, in that it will not cross from the content of a structure into
+the elements that define the structure.
+
 =cut
 
 sub previous_sibling {
     my ( $self ) = @_;
-    my ( $method, $inx ) = $self->_my_inx()
+    my ( $method, $inx ) = $self->__my_nav()
 	or return;
     $inx or return;
     return $self->_parent()->$method( $inx - 1 );
 }
 
+=head2 remove_insignificant
+
+This method returns a new object manufactured from the invocant, but
+containing only elements for which C<< $elem->significant() >> returns a
+true value.
+
+If you call this method on a L<PPIx::Regexp::Node|PPIx::Regexp::Node>
+you will get back a deep clone, but without the insignificant elements.
+
+If you call this method on any other L<PPIx::Regexp|PPIx::Regexp> class
+you will get back either the invocant or nothing. This may change to a
+clone of the invocant or nothing if unforseen problems arise with
+returning the invocant, or if objects become mutable (unlikely, but not
+impossible.)
+
+=cut
+
+sub remove_insignificant {
+    my ( $self ) = @_;
+    $self->significant()
+	and return $self;
+    return;
+}
+
 =head2 requirements_for_perl
 
  say $token->requirements_for_perl();
@@ -439,6 +505,20 @@ This method returns a string representing the Perl requirements for a
 given module. This should only be used for informational purposes, as
 the format of the string may be subject to change.
 
+At the moment, the returns may be:
+
+ version <= $]
+ version <= $] < version
+ two or more of the above joined by '||'
+ ! $]
+
+The last means that, although all the components of the regular
+expression can be compiled by B<some> version of Perl, there is no
+version that will compile all of them.
+
+I reiterate: the returned string may be subject to change, maybe without
+warning.
+
 This method was added in version 0.051_01.
 
 =cut
@@ -446,11 +526,13 @@ This method was added in version 0.051_01.
 sub requirements_for_perl {
     my ( $self ) = @_;
     my @req;
-    foreach my $r ( @{ $self->__structured_requirements_for_perl( [] ) } ) {
+    foreach my $r ( @{ $self->__structured_requirements_for_perl() || [] } ) {
 	push @req, defined $r->{removed} ?
 	"$r->{introduced} <= \$] < $r->{removed}" :
 	"$r->{introduced} <= \$]";
     }
+    @req
+	or return '! $]';
     return join ' || ', @req;
 }
 
@@ -486,11 +568,42 @@ sub significant {
     return 1;
 }
 
+=head2 snext_element
+
+This method returns the next significant element, or nothing if
+there is none.
+
+Unlike L<snext_sibling()|/snext_sibling>, this will cross from
+the content of a structure into the elements that define the structure,
+or vice versa.
+
+=cut
+
+sub snext_element {
+    my ( $self ) = @_;
+    my $inx = $self->__my_inx();
+    my $parent = $self->_parent()
+	or return;
+    my @elem = $parent->elements();
+    while ( 1 ) {
+	$inx++;
+	$elem[$inx]
+	    or last;
+	$elem[$inx]->significant()
+	    and return $elem[$inx];
+    }
+    return;
+}
+
 =head2 snext_sibling
 
 This method returns the element's next significant sibling, or nothing
 if there is none.
 
+This method is analogous to the same-named L<PPI::Element|PPI::Element>
+method, in that it will not cross from the content of a structure into
+the elements that define the structure.
+
 =cut
 
 sub snext_sibling {
@@ -502,11 +615,40 @@ sub snext_sibling {
     return;
 }
 
+=head2 sprevious_element
+
+This method returns the previous significant element, or nothing if
+there is none.
+
+Unlike L<sprevious_sibling()|/sprevious_sibling>, this will cross from
+the content of a structure into the elements that define the structure,
+or vice versa.
+
+=cut
+
+sub sprevious_element {
+    my ( $self ) = @_;
+    my $inx = $self->__my_inx()
+	or return;
+    my $parent = $self->_parent()
+	or return;
+    my @elem = $parent->elements();
+    while ( $inx ) {
+	$elem[--$inx]->significant()
+	    and return $elem[$inx];
+    }
+    return;
+}
+
 =head2 sprevious_sibling
 
 This method returns the element's previous significant sibling, or
 nothing if there is none.
 
+This method is analogous to the same-named L<PPI::Element|PPI::Element>
+method, in that it will not cross from the content of a structure into
+the elements that define the structure.
+
 =cut
 
 sub sprevious_sibling {
@@ -523,36 +665,51 @@ sub sprevious_sibling {
 # stable. The exposure would be
 # sub structured_requirements_for_perl {
 #     my ( $self ) = @_;
-#     return $self->__structured_requirements_for_perl( [] );
+#     return $self->__structured_requirements_for_perl();
 # }
+# The return ia a reference to an array of hashes. Each hash contains
+# key {introduced} (the version the element was introduced) and MAYBE
+# key {removed} (the version the element was removed). There may be more
+# than one such, and their ranges will not overlap.
 sub __structured_requirements_for_perl {
     my ( $self, $rslt ) = @_;
-    if ( @{ $rslt } ) {
-	my @merged;
-	foreach my $left ( $self->__perl_requirements() ) {
-	    foreach my $right ( @{ $rslt } ) {
-		my $min = max( $left->{introduced}, $right->{introduced} );
-		my $max = defined $left->{removed} ?
-		    defined $right->{removed} ?
-			min( $left->{removed}, $right->{removed} ) :
-			$left->{removed} :
-		    $right->{removed};
-		defined $max
-		    and $max <= $min
-		    and next;
-		push @merged, {
-		    introduced	=> $min,
-		    removed		=> $max,
-		};
-	    }
+    $rslt ||= $self->__structured_requirements_for_any_perl();
+
+    my @merged;
+    foreach my $left ( $self->__perl_requirements() ) {
+	foreach my $right ( @{ $rslt } ) {
+	    my $min = max( $left->{introduced}, $right->{introduced} );
+	    my $max = defined $left->{removed} ?
+		defined $right->{removed} ?
+		    min( $left->{removed}, $right->{removed} ) :
+		    $left->{removed} :
+		$right->{removed};
+	    defined $max
+		and $max <= $min
+		and next;
+	    push @merged, {
+		introduced	=> $min,
+		removed		=> $max,
+	    };
 	}
-	@{ $rslt } = @merged;
-    } else {
-	@{ $rslt } = $self->__perl_requirements();
     }
+    @{ $rslt } = @merged;
+
     return $rslt;
 }
 
+# NOTE: This method is to be used ONLY to initialize
+# __structured_requirements_for_perl(). It returns a structure that
+# matches any Perl.
+sub __structured_requirements_for_any_perl {
+    return [
+	{
+	    introduced	=> MINIMUM_PERL,
+	    removed	=> undef,
+	},
+    ];
+}
+
 =head2 tokens
 
 This method returns all tokens contained in the element.
@@ -630,6 +787,21 @@ sub nav {
     return ( $parent->nav(), $parent->__nav( $self ) );
 }
 
+# Find our index among the parents children. If not found, just return.
+# Unlike __my_nav(), this just returns an index, which is appropriate
+# for ->element( $inx ), or would be if element() existed.
+
+sub __my_inx {
+    my ( $self ) = @_;
+    my $parent = $self->_parent() or return;
+    my $addr = refaddr( $self );
+    my $inx = firstidx { refaddr $_ == $addr } $parent->elements();
+    $inx < 0
+	and return;
+    return $inx;
+}
+
+
 # Find our location and index among the parent's children. If not found,
 # just returns.
 
@@ -637,7 +809,8 @@ sub nav {
     my %method_map = (
 	children => 'child',
     );
-    sub _my_inx {
+
+    sub __my_nav {
 	my ( $self ) = @_;
 	my $parent = $self->_parent() or return;
 	my $addr = refaddr( $self );
