@@ -37,10 +37,14 @@ use base qw{ PPIx::Regexp::Token::Code };
 use Carp qw{ confess };
 use PPI::Document;
 use PPIx::Regexp::Constant qw{
-    COOKIE_CLASS COOKIE_REGEX_SET TOKEN_LITERAL MINIMUM_PERL
+    COOKIE_CLASS
+    COOKIE_REGEX_SET
+    MINIMUM_PERL
+    TOKEN_LITERAL
+    @CARP_NOT
 };
 
-our $VERSION = '0.055';
+our $VERSION = '0.062';
 
 use constant VERSION_WHEN_IN_REGEX_SET => '5.017009';
 
